pub fn format_checked_verbose(file: &CheckedFile) -> StringExpand description
Format a verbose line for a checked file, including cache status tags.
pub fn format_checked_verbose(file: &CheckedFile) -> StringFormat a verbose line for a checked file, including cache status tags.