pub async fn run(
args: &mut ValidateArgs,
reporter: &mut dyn Reporter,
) -> Result<bool>Expand description
Run validation and report results via the given reporter.
Returns true if there were validation errors, false if clean.
Errors
Returns an error if file collection or schema validation encounters an I/O error.