run_with

Function run_with 

pub async fn run_with(
    args: &ValidateArgs,
    cache: Option<SchemaCache>,
    on_check: impl FnMut(&CheckedFile),
) -> Result<ValidateResult>
Like run, but calls on_check each time a file is checked, allowing callers to stream progress (e.g. verbose output) as files are processed.

Errors

Returns an error if file collection or schema validation encounters an I/O error.