try_parse_all

Function try_parse_all 

pub fn try_parse_all(
    content: &str,
    file_name: &str,
) -> Option<(FileFormat, Value)>
Try parsing content with each known format, returning the first success.

JSONC is tried first (superset of JSON, handles comments), then YAML and TOML which cover the most common config formats, followed by the rest.