pub fn load_config(
search_dir: Option<&Path>,
) -> (Config, PathBuf, Option<PathBuf>)Expand description
Locate lintel.toml, load the full config, and return the config directory.
Returns (config, config_dir, config_path). When no config is found or
cwd is unavailable the config is default and config_path is None.