pub fn try_parse_all(
content: &str,
file_name: &str,
) -> Option<(FileFormat, Value)>Expand description
Try parsing content with each known format, returning the first success.
JSONC is tried first (superset of JSON, handles comments), then YAML and TOML which cover the most common config formats, followed by the rest.